==> django-cqrs-1.4.2.tar.gz: django-cqrs-1.4.2/docs/conf.py <==
import os
import sys
from datetime import datetime

from setuptools_scm import get_version

import django


sys.path.insert(0, os.path.abspath('..'))
os.environ['DJANGO_SETTINGS_MODULE'] = 'tests.dj.settings'
django.setup()


# -- Project information -----------------------------------------------------

project = 'django-cqrs'
copyright = '{}, CloudBlue Inc.'.format(datetime.now().year)
author = 'CloudBlue'

# The full version, including alpha/beta/rc tags
release = get_version(root='..', relative_to=__file__)


# -- General configuration ---------------------------------------------------

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = [
    'sphinx.ext.autodoc',
    'sphinx.ext.autosectionlabel',
    'sphinx_copybutton',
]

autosectionlabel_prefix_document = True
autodoc_member_order = 'bysource'

# Add any paths that contain templates here, relative to this directory.
templates_path = ['_templates']

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path.
exclude_patterns = ['_build', 'Thumbs.db', '.DS_Store']


# -- Options for HTML output -------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
html_theme = 'sphinx_rtd_theme'

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ['_static']

==> django-cqrs-1.11.2.tar.gz: django-cqrs-1.11.2/docs/conf.py <==
#  Copyright © 2021 Ingram Micro Inc. All rights reserved.

import os
import sys
from datetime import datetime

from setuptools_scm import get_version

import django


sys.path.insert(0, os.path.abspath('..'))
os.environ['DJANGO_SETTINGS_MODULE'] = 'tests.dj.settings'
django.setup()


# -- Project information -----------------------------------------------------

project = 'django-cqrs'
copyright = '{}, Ingram Micro Inc.'.format(datetime.now().year)
author = 'CloudBlue'

# The full version, including alpha/beta/rc tags
release = get_version(root='..', relative_to=__file__)


# -- General configuration ---------------------------------------------------

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = [
    'sphinx.ext.autodoc',
    'sphinx.ext.autosectionlabel',
    'sphinx_copybutton',
]

autosectionlabel_prefix_document = True
autodoc_member_order = 'bysource'

# Add any paths that contain templates here, relative to this directory.
templates_path = ['_templates']

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path.
exclude_patterns = ['_build', 'Thumbs.db', '.DS_Store']


# -- Options for HTML output -------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
html_theme = 'sphinx_rtd_theme'

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ['_static']

# These paths are either relative to html_static_path
# or fully qualified paths (eg. https://...)
html_css_files = [
    'css/custom.css',
]
